<?php
// Start output buffering
ob_start();

// Enable error reporting for debugging (set display_errors to 0 in production)
error_reporting(E_ALL);
ini_set('display_errors', 0); // Set to 1 only during development

require 'vendor/autoload.php';

use net\authorize\api\contract\v1 as AnetAPI;
use net\authorize\api\controller as AnetController;

// Set the content type to application/json
header('Content-Type: application/json');

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Collect input data
    $amount = $_POST['amount'] ?? null;
    $cardNumber = $_POST['cardNumber'] ?? null;
    $expMonth = $_POST['expMonth'] ?? null;
    $expYear = $_POST['expYear'] ?? null;
    $cvv = $_POST['cvv'] ?? null;

    // Validate input data
    if (!$amount || !$cardNumber || !$expMonth || !$expYear || !$cvv) {
        echo json_encode(['success' => false, 'message' => 'All fields are required']);
        exit;
    }

    // Authorize.Net credentials
    $merchantAuthentication = new AnetAPI\MerchantAuthenticationType();
    $merchantAuthentication->setName("28tez7VTb");
    $merchantAuthentication->setTransactionKey("4N9pRHk2Fn9682N4");

    // Create payment data
    $creditCard = new AnetAPI\CreditCardType();
    $creditCard->setCardNumber($cardNumber);
    $creditCard->setExpirationDate("$expYear-$expMonth");
    $creditCard->setCardCode($cvv);

    $paymentType = new AnetAPI\PaymentType();
    $paymentType->setCreditCard($creditCard);

    // Set transaction request
    $transactionRequest = new AnetAPI\TransactionRequestType();
    $transactionRequest->setTransactionType("authCaptureTransaction");
    $transactionRequest->setAmount($amount);
    $transactionRequest->setPayment($paymentType);

    // Create transaction request
    $request = new AnetAPI\CreateTransactionRequest();
    $request->setMerchantAuthentication($merchantAuthentication);
    $request->setTransactionRequest($transactionRequest);

    // Process transaction
    // $controller = new AnetController\CreateTransactionController($request);
    // $response = $controller->executeWithApiResponse(\net\authorize\api\constants\ANetEnvironment::SANDBOX);
    $controller = new AnetController\CreateTransactionController($request);
    $response = $controller->executeWithApiResponse(\net\authorize\api\constants\ANetEnvironment::PRODUCTION);

    // Handle response
    if ($response != null && $response->getMessages()->getResultCode() == "Ok") {
        $transactionResponse = $response->getTransactionResponse();
        if ($transactionResponse != null && $transactionResponse->getMessages() != null) {
            // Successful payment
            echo json_encode([
                'success' => true,
                'transactionId' => $transactionResponse->getTransId() ?? null,
                'message' => $transactionResponse->getMessages()[0]->getDescription() ?? null
            ]);
        } else {
            // No response from transaction
            echo json_encode(['success' => false, 'message' => 'Payment Failed: No response from transaction']);
        }
    } else {
        // Payment failed
        $errorMessages = $response ? $response->getMessages()->getMessage() : [];
        $errorCode = $errorMessages[0]->getCode() ?? 'N/A';
        $errorText = $errorMessages[0]->getText() ?? 'Unknown error occurred';

        echo json_encode([
            'success' => false,
            'message' => 'Payment Failed',
            'errorCode' => $errorCode,
            'errorMessage' => $errorText
        ]);
    }
} else {
    // Invalid request method
    echo json_encode(['success' => false, 'message' => 'Invalid request method']);
}

// End output buffering and flush
ob_end_flush();
?>
